==> okteta-14.12.1.tar.xz: okteta-14.12.1/kasten/controllers/view/poddecoder/abstractdifferentsizedialog.h <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef ABSTRACTDIFFERENTSIZEDIALOG_H
#define ABSTRACTDIFFERENTSIZEDIALOG_H

// Kasten core
#include <kastencore.h>


namespace Kasten
{

class AbstractDifferentSizeDialog
{
  protected:
    AbstractDifferentSizeDialog();

  public:
    virtual ~AbstractDifferentSizeDialog();

  public: // API to be implemented
    virtual Answer query( int newValueSize, int oldValueSize, int sizeLeft ) = 0;
};


inline AbstractDifferentSizeDialog::AbstractDifferentSizeDialog() {}
inline AbstractDifferentSizeDialog::~AbstractDifferentSizeDialog() {}

}

#endif

==> okteta-16.03.80.tar.xz: okteta-16.03.80/kasten/controllers/view/poddecoder/abstractdifferentsizedialog.h <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef ABSTRACTDIFFERENTSIZEDIALOG_H
#define ABSTRACTDIFFERENTSIZEDIALOG_H

// Kasten core
#include <kasten/kastencore.h>


namespace Kasten
{

class AbstractDifferentSizeDialog
{
  protected:
    AbstractDifferentSizeDialog();

  public:
    virtual ~AbstractDifferentSizeDialog();

  public: // API to be implemented
    virtual Answer query( int newValueSize, int oldValueSize, int sizeLeft ) = 0;
};


inline AbstractDifferentSizeDialog::AbstractDifferentSizeDialog() {}
inline AbstractDifferentSizeDialog::~AbstractDifferentSizeDialog() {}

}

#endif
